@@ -297,6 +297,50 @@ async def test_run_background_tasks_even_if_client_disconnects() -> None:
     assert background_task_run.is_set()
 
 
+def test_run_background_tasks_raise_exceptions(test_client_factory: TestClientFactory) -> None:
+    # test for https://github.com/encode/starlette/issues/2625
+
+    async def sleep_and_set() -> None:
+        await anyio.sleep(0.1)
+        raise ValueError("TEST")
+
+    async def endpoint_with_background_task(_: Request) -> PlainTextResponse:
+        return PlainTextResponse(background=BackgroundTask(sleep_and_set))
+
+    async def passthrough(request: Request, call_next: RequestResponseEndpoint) -> Response:
+        return await call_next(request)
+
+    app = Starlette(
+        middleware=[Middleware(BaseHTTPMiddleware, dispatch=passthrough)],
+        routes=[Route("/", endpoint_with_background_task)],
+    )
+
+    client = test_client_factory(app)
+    with pytest.raises(ValueError, match="TEST"):
+        client.get("/")
+
+
+def test_exception_can_be_caught(test_client_factory: TestClientFactory) -> None:
+    async def error_endpoint(_: Request) -> None:
+        raise ValueError("TEST")
+
+    async def catches_error(request: Request, call_next: RequestResponseEndpoint) -> Response:
+        try:
+            return await call_next(request)
+        except ValueError as exc:
+            return PlainTextResponse(content=str(exc), status_code=400)
+
+    app = Starlette(
+        middleware=[Middleware(BaseHTTPMiddleware, dispatch=catches_error)],
+        routes=[Route("/", error_endpoint)],
+    )
+
+    client = test_client_factory(app)
+    response = client.get("/")
+    assert response.status_code == 400
+    assert response.text == "TEST"
+
+
 @pytest.mark.anyio
 async def test_do_not_block_on_background_tasks() -> None:
     response_complete = anyio.Event()
